Specify the default language to interpret the search string. xx is the language’s ISO 639-1 language code, while the optional YY value is the two-letter ISO 3166-1 country code.
You can use the country code that you provide in locale to differentiate between dialects of the given language.
The default value is en_US.
Filter the Response Objects to only include GIFs with aspect ratios that fit within the selected range.
The default value is all. The accepted values are all, wide, and standard:
Comma-separated list of GIF formats to filter the Response Objects. By default, media_filter returns all formats for each Response Object.
Example: media_filter=gif,tinygif,mp4,tinymp4
Doesn’t have a default value.
Comma-separated list of non-GIF content types to filter the Response Objects. By default, searchfilter returns GIF content only.
Doesn’t have a default value. The accepted values are sticker, static, and -static: